# -*- coding: utf-8 -*-
"""This module contains the controller classes of the application."""

# symbols which are imported by "from wiki20.controllers import *"
__all__ = ['Root']

# standard library imports
import logging
import re

# third-party imports
from turbogears import controllers, expose, flash
from turbogears import redirect, url

# project specific imports
from wiki20.model import Page, session
from docutils.core import publish_parts


log = logging.getLogger("wiki20.controllers")


wikiwords = re.compile(r"\b([A-Z]\w+[A-Z]+\w+)")


class Root(controllers.RootController):

    @expose('wiki20.templates.page')
    def index(self, pagename='FrontPage'):
        page = Page.query.get(pagename)
        if not page:
            raise redirect('notfound', pagename=pagename)
        page = Page.query.get(pagename)
        content = publish_parts(page.data,
            writer_name='html')['html_body']
        root = str(url('/'))
        content = wikiwords.sub(r'<a href="%s\1">\1</a>' % root, content)
        return dict(data=content, page=page)

    @expose('wiki20.templates.edit')
    def notfound(self, pagename):
        page = Page(pagename=pagename, data="")
        session.add(page)
        return dict(page=page)

    @expose('wiki20.templates.edit')
    def edit(self, pagename):
        page = Page.query.get(pagename)
        return dict(page=page)

    @expose('wiki20.templates.pagelist')
    @expose('json')
    def pagelist(self):
        pages = [value[0] for value in
            Page.query.order_by(Page.pagename).values(Page.pagename)]
        return dict(pages=pages)

    @expose()
    def save(self, pagename, data, submit):
        page = Page.query.get(pagename)
        page.data = data
        flash("Changes saved!")
        raise redirect('/' + pagename)

    @expose()
    def default(self, pagename):
        return self.index(pagename)
